# eo-learn-stac

[eo-learn](https://eo-learn.readthedocs.io/en/latest/) tasks for consuming
[SpatioTemporal Asset Catalogs](https://stacspec.org/) (STAC).

It provides a `STACInputTask` task class that, similarly to `SentinelHubInputTask`,
queries a STAC catalog, fetches images from a time interval and bounding box, 
and finally creates time-dependant EOPatches.

*Work in progress*

<!-- pyscaffold-notes -->

## Contributing

Bug reports and pull requests are welcome on GitHub at the [issues
page](https://github.com/dymaxionlabs/eolearn-stac). This project is intended
to be a safe, welcoming space for collaboration, and contributors are expected
to adhere to the [Contributor Covenant](http://contributor-covenant.org) code
of conduct.

## License

This project is licensed under MIT. Refer to [LICENSE.txt](LICENSE.txt).
